#[non_exhaustive]
pub enum Request<'a> { Destroy, SetSandboxEngine { name: String, }, SetAppId { app_id: String, }, SetInstanceId { instance_id: String, }, Commit, }
Available on crate feature wayland and Linux only.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Destroy

destroy the security context object

Destroy the security context object.

This is a destructor, once sent this object cannot be used any longer.



SetSandboxEngine

set the sandbox engine

Attach a unique sandbox engine name to the security context. The name should follow the reverse-DNS style (e.g. “org.flatpak”).

A list of well-known engines is maintained at: https://gitlab.freedesktop.org/wayland/wayland-protocols/-/blob/main/staging/security-context/engines.md

It is a protocol error to call this request twice. The already_set error is sent in this case.

Fields

name: String

the sandbox engine name



SetAppId

set the application ID

Attach an application ID to the security context.

The application ID is an opaque, sandbox-specific identifier for an application. See the well-known engines document for more details: https://gitlab.freedesktop.org/wayland/wayland-protocols/-/blob/main/staging/security-context/engines.md

The compositor may use the application ID to group clients belonging to the same security context application.

Whether this request is optional or not depends on the sandbox engine used.

It is a protocol error to call this request twice. The already_set error is sent in this case.

Fields

app_id: String

the application ID



SetInstanceId

set the instance ID

Attach an instance ID to the security context.

The instance ID is an opaque, sandbox-specific identifier for a running instance of an application. See the well-known engines document for more details: https://gitlab.freedesktop.org/wayland/wayland-protocols/-/blob/main/staging/security-context/engines.md

Whether this request is optional or not depends on the sandbox engine used.

It is a protocol error to call this request twice. The already_set error is sent in this case.

Fields

instance_id: String

the instance ID



Commit

register the security context

Atomically register the new client and attach the security context metadata.

If the provided metadata is inconsistent or does not match with out of band metadata (see https://gitlab.freedesktop.org/wayland/wayland-protocols/-/blob/main/staging/security-context/engines.md), the invalid_metadata error may be sent eventually.

It’s a protocol error to send any request other than “destroy” after this request. In this case, the already_used error is sent.

Implementations



impl<'a> Request<'a>

pub fn opcode(&self) -> u16

Get the opcode number of this message