Struct WpSecurityContextV1
pub struct WpSecurityContextV1 { /* private fields */ }wayland and Linux only.Expand description
client security context
The security context allows a client to register a new client and attach security context metadata to the connections.
When both are set, the combination of the application ID and the sandbox engine must uniquely identify an application. The same application ID will be used across instances (e.g. if the application is restarted, or if the application is started multiple times).
When both are set, the combination of the instance ID and the sandbox engine must uniquely identify a running instance of an application.
This interface has no events.
Implementations
impl WpSecurityContextV1
impl WpSecurityContextV1
pub fn destroy(&self)
pub fn destroy(&self)
destroy the security context object
Destroy the security context object.
pub fn set_sandbox_engine(&self, name: String)
pub fn set_sandbox_engine(&self, name: String)
set the sandbox engine
Attach a unique sandbox engine name to the security context. The name should follow the reverse-DNS style (e.g. “org.flatpak”).
A list of well-known engines is maintained at: https://gitlab.freedesktop.org/wayland/wayland-protocols/-/blob/main/staging/security-context/engines.md
It is a protocol error to call this request twice. The already_set error is sent in this case.
pub fn set_app_id(&self, app_id: String)
pub fn set_app_id(&self, app_id: String)
set the application ID
Attach an application ID to the security context.
The application ID is an opaque, sandbox-specific identifier for an application. See the well-known engines document for more details: https://gitlab.freedesktop.org/wayland/wayland-protocols/-/blob/main/staging/security-context/engines.md
The compositor may use the application ID to group clients belonging to the same security context application.
Whether this request is optional or not depends on the sandbox engine used.
It is a protocol error to call this request twice. The already_set error is sent in this case.
pub fn set_instance_id(&self, instance_id: String)
pub fn set_instance_id(&self, instance_id: String)
set the instance ID
Attach an instance ID to the security context.
The instance ID is an opaque, sandbox-specific identifier for a running instance of an application. See the well-known engines document for more details: https://gitlab.freedesktop.org/wayland/wayland-protocols/-/blob/main/staging/security-context/engines.md
Whether this request is optional or not depends on the sandbox engine used.
It is a protocol error to call this request twice. The already_set error is sent in this case.
pub fn commit(&self)
pub fn commit(&self)
register the security context
Atomically register the new client and attach the security context metadata.
If the provided metadata is inconsistent or does not match with out of band metadata (see https://gitlab.freedesktop.org/wayland/wayland-protocols/-/blob/main/staging/security-context/engines.md), the invalid_metadata error may be sent eventually.
It’s a protocol error to send any request other than “destroy” after this request. In this case, the already_used error is sent.